import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_slick/navigation/menu_configuration.dart';
import 'package:flutter_slick/navigation/route_configuration.dart';
import 'package:flutter_slick/theme/slick_colors.dart';

import '../slick.dart';
import '../slick_controls.dart';

///Some sort of comment
class SlickConfiguration {
  static void set({
    Widget unknownScreen,
    Widget errorScreen,
    Widget waitingScreen,
    List<RouteInfo> routes,
    RouteInfo dashboardRoute,
    List<Menu> menus,
    SlickColors colors,
    Completer<void> isAppInitialised,
  }) {
    if (unknownScreen != null) SlickConfiguration.unknownScreen = unknownScreen;
    if (errorScreen != null) SlickConfiguration.errorScreen = errorScreen;
    if (waitingScreen != null) SlickConfiguration.waitingScreen = waitingScreen;
    if (routes != null) SlickConfiguration.routes = routes;
    if (dashboardRoute != null)
      SlickConfiguration.dashboardRoute = dashboardRoute;
    if (menus != null) SlickConfiguration.menus = menus;
    if (colors != null) SlickConfiguration.colors = colors;
    if (isAppInitialised != null)
      SlickConfiguration.isAppInitialised = isAppInitialised;
  }

  static Widget unknownScreen;
  static Widget errorScreen;
  static Widget waitingScreen;

  static Widget getWaitingScreen() {
    if (waitingScreen != null) return waitingScreen;

    return Scaffold(
      body: Center(
        child: CircularProgressIndicator(),
      ),
    );
  }

  static Widget getUnknownScreen() {
    if (unknownScreen != null) return unknownScreen;

    return Scaffold(
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Text(
              'The route you have found yourself at does not exist. So sorry :(',
            ),
            SizedBox(
              height: 10,
            ),
            SlickElevatedButton(
              onPressed: () => currentRouteSingleton.navigateHome(),
              child: Text('Ok'),
            ),
          ],
        ),
      ),
    );
  }

  static Widget getErrorScreen() {
    if (errorScreen != null) return errorScreen;

    return Scaffold(
      body: Center(
        child: Text('${BaseLogic.mostRecentError}'),
      ),
    );
  }

  static List<RouteInfo> routes;
  static RouteInfo dashboardRoute;
  static List<Menu> menus;

  static SlickColors colors;

  static Completer<void> isAppInitialised;
}
