import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_slick/configuration/slick_configuration.dart';
import 'package:flutter_slick/navigation/route_configuration.dart';
import 'package:flutter_slick/state/base_logic.dart';

class SlickScreen extends ConsumerWidget {
  @override
  Widget build(BuildContext context, ScopedReader watch) {
    currentRouteSingleton.building = true;
    var provider = currentRouteSingleton.logicForRoute();

    var showProgressInidcator = false;

    Widget bodyWidget;
    if (provider != null) {
      var baseLogic = watch(provider);
      if (baseLogic == null) return SlickConfiguration.getUnknownScreen();

      if (currentRouteSingleton.reInit) {
        baseLogic.deactivate();
      }

      if (currentRouteSingleton.reInit ||
          (!baseLogic.initialised && !baseLogic.ready && !baseLogic.hasError)) {
        logicInit(baseLogic);
      }

      if (baseLogic.hasError) {
        bodyWidget = SlickConfiguration.getErrorScreen();
      } else if (!baseLogic.initialised) {
        bodyWidget = SlickConfiguration.getWaitingScreen();
      } else if (baseLogic.initialised) {
        if (!baseLogic.ready) showProgressInidcator = true;
        bodyWidget = currentRouteSingleton.screenForRoute();
      } else {
        bodyWidget = SlickConfiguration.getWaitingScreen();
      }
    } else {
      bodyWidget = SlickConfiguration.getWaitingScreen();
    }

    currentRouteSingleton.building = false;

    return Stack(
      children: [
        bodyWidget,
        if (showProgressInidcator)
          Center(
            child: CircularProgressIndicator(),
          ),
      ],
    );
  }

  void logicInit(BaseLogic baseLogic) async {
    if (SlickConfiguration.isAppInitialised != null &&
        !SlickConfiguration.isAppInitialised.isCompleted) {
      await SlickConfiguration.isAppInitialised.future;
    }

    if (!baseLogic.hasViewAccess) {
      baseLogic.setError('You don\'t have permission for this route');
    } else {
      baseLogic.init();
    }
  }
}
